API Reference
#############


UFS Datasets
------------

.. autosummary::
   :toctree: generated/

   ufs2arco.FV3Dataset
   ufs2arco.MOM6Dataset
   ufs2arco.CICE6Dataset


Regridding
----------

.. autosummary::
   :toctree: generated/

   ufs2arco.Layers2Pressure
   ufs2arco.MOM6Regridder
   ufs2arco.CICE6Regridder


Data Sources
------------

.. autosummary::
   :toctree: generated/

   ufs2arco.sources.Source
   ufs2arco.sources.AnalysisSource
   ufs2arco.sources.EnsembleForecastSource
   ufs2arco.sources.AWSGEFSArchive

Data Targets
------------

.. autosummary::
   :toctree: generated/

   ufs2arco.targets.Target
   ufs2arco.targets.Anemoi
